Structs
- Actor
Path - Actor
Ref - A lightweight, typed reference to interact with its underlying actor instance through concurrent messaging.
- Actor
Selection - A selection represents part of the actor heirarchy, allowing messages to be sent to all actors in the selection.
- Actor
Uri - An
ActorUrirepresents the location of an actor, including the path and actor system host. - All
- A channel topic representing all topics
* - Basic
Actor Ref - A lightweight, un-typed reference to interact with its underlying actor instance through concurrent messaging.
- Channel
- A specialized actor for providing Publish/Subscribe capabilities for user level messages
- Context
- Provides context, including the actor system during actor execution.
- Dead
Letter - Events
Channel - A specialized channel that publishes messages as system messages
- Props
- Provides instances of
ActorProducerfor use when creating Actors (actor_of_props). - Publish
- Restart
Error - Error type when an actor fails to restart.
- Subscribe
- Topic
- When publishing a message to a channel a Topic is provided.
- TryMsg
Error - Error type when an
try_tellfails onOption<ActorRef<Msg>> - Unsubscribe
- Unsubscribe
All
Enums
- Channel
Msg - Create
Error - Error type when an actor fails to start during
actor_of. - Strategy
- Supervision strategy
- SysTopic
- System topics used by the
event_streamchannel
Traits
- Actor
- Actor
Args - Actor
Factory - Actor
Factory Args - Actor
Producer - Represents the underlying Actor factory function for creating instances of
Actor. - Actor
RefFactory - Produces
ActorRefs.actor_ofblocks on the current thread until the actor has successfully started or failed to start. - Actor
Reference - Actor
Selection Factory - Receive
- Receive and handle a specific message type
- Tell
- TmpActor
RefFactory - Produces
ActorRefs under thetempguardian actor.
Functions
Type Aliases
- BoxActor
- The actor trait object
- BoxActor
Prod - A
Clone,SendandSyncActorProducer - Boxed
Tell - Channel
Ref - DLChannel
Msg - MsgResult
- Sender